@@ -27,8 +27,17 @@ sub new_from_url {
     my $req = GET $args{url};
     my $ua  = LWP::UserAgent->new;
 
+    if ( defined $args{ssl_opts} ) {
+        require LWP::Protocol::https;
+        $ua->ssl_opts( %{$args{ssl_opts}} );
+    }
+
     my $res = $ua->request($req);
-    die "no metadata" unless $res->is_success;
+    if (! $res->is_success ) {
+        my $msg = "no metadata: " . $res->code . ": " . $res->message . "\n";
+        die $msg;
+    }
+
     my $xml = $res->content;
 
     return $class->new_from_xml(xml => $xml, cacert => $args{cacert});
@@ -222,11 +231,20 @@ Net::SAML2::IdP
 
 =head1 VERSION
 
-version 0.38
+version 0.40
 
 =head1 SYNOPSIS
 
-  my $idp = Net::SAML2::IdP->new_from_url( url => $url, cacert => $cacert );
+  my $idp = Net::SAML2::IdP->new_from_url(
+        url => $url,
+        cacert => $cacert,
+        ssl_opts =>         # Optional options supported by LWP::Protocol::https
+            {
+                SSL_ca_file     => '/your/directory/cacert.pem',
+                SSL_ca_path     => '/etc/ssl/certs',
+                verify_hostname => 1,
+            }
+        );
   my $sso_url = $idp->sso_url('urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect');
 
 =head1 NAME
@@ -245,11 +263,11 @@ Constructor
 
 =back
 
-=head2 new_from_url( url => $url, cacert => $cacert )
+=head2 new_from_url( url => $url, cacert => $cacert, ssl_opts => {} )
 
 Create an IdP object by retrieving the metadata at the given URL.
 
-Dies if the metadata can't be retrieved.
+Dies if the metadata can't be retrieved with reason.
 
 =head2 new_from_xml( xml => $xml, cacert => $cacert )
 
